@@ -1,3 +1,5 @@
+use flexi_logger::{Duplicate, FileSpec, Logger};
+use log::{debug, info};
 use std::collections::HashMap;
 use std::str::FromStr;
 use ticket2ride::{max_key, City};
@@ -8,8 +10,18 @@ mod routing;
 mod scoring;
 
 fn main() {
+    // Get command line options
     let matches = cli::get_cli().get_matches();
 
+    // Setup logging first
+    Logger::try_with_env_or_str(matches.value_of("logging").unwrap_or("none"))
+        .unwrap()
+        .log_to_file(FileSpec::default())
+        .duplicate_to_stderr(Duplicate::Info)
+        .start()
+        .unwrap();
+    debug!("Debug reporting turned on!");
+
     let startcity = matches.value_of("city").unwrap_or("Edinburgh");
     /* These functions come from the experiment.rs file where I keep
      * demo functions to test various functionality. In this way, I
@@ -22,7 +34,9 @@ fn main() {
 
     //experiment::demo_dijkstra();
 
+    info!("Start traversing the network.");
     let routes = routing::traverse(City::from_str(startcity).unwrap());
+    info!("Start computing scores for all routes.");
     let mut scores: HashMap<u32, u16> = HashMap::new();
     for (id, route) in routes.iter() {
         let score: u16 = scoring::get_scores(route.to_vec());
